@@ -12,11 +12,11 @@ Net::SMTP::Bulk::AnyEvent - NonBlocking batch SMTP using Net::SMTP interface cia
 
 =head1 VERSION
 
-Version 0.22
+Version 0.23
 
 =cut
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 =head2 new(%options, Hosts=>[\%options2,\%options3])
 
@@ -729,7 +729,7 @@ sub _DATAEND {
     my $write = $self->{on_queue}{ $k->[0] }{ $k->[1] }{data}."\r\n.";
     
     if ( $self->{pipe_mode}{ $k->[0] }{ $k->[1] }[0] < 2 ) {
-	    $write = join("\n",@{ $self->{pipe_mode}{ $k->[0] }{ $k->[1] }[1] })."\n".$write;
+	    $write = join("\n", (@{ $self->{pipe_mode}{ $k->[0] }{ $k->[1] }[1] },$write) );
 		$self->{pipe_mode}{ $k->[0] }{ $k->[1] }[1]=[];
         $self->_WRITE( $k, $write );
 
